@@ -8,16 +8,19 @@ require Exporter;
 require DynaLoader;
 our @ISA = qw(Exporter DynaLoader);
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 # use all files under Ogre/ - probably not a good idea
+use Ogre::BillboardChain;
 use Ogre::Camera;
 use Ogre::ColourValue;
 use Ogre::ConfigFile;
 use Ogre::Degree;
 use Ogre::Entity;
+use Ogre::Frustum;
 use Ogre::Light;
 use Ogre::LogManager;
+use Ogre::ManualObject;
 use Ogre::MaterialManager;
 use Ogre::MeshManager;
 use Ogre::MeshPtr;
@@ -27,6 +30,7 @@ use Ogre::Overlay;
 use Ogre::OverlayContainer;
 use Ogre::OverlayElement;
 use Ogre::OverlayManager;
+use Ogre::ParticleSystem;
 use Ogre::Plane;
 use Ogre::Quaternion;
 use Ogre::Radian;
@@ -34,6 +38,7 @@ use Ogre::Renderable;
 use Ogre::RenderTarget;
 use Ogre::RenderWindow;
 use Ogre::ResourceGroupManager;
+use Ogre::RibbonTrail;
 use Ogre::Root;
 use Ogre::SceneManager;
 use Ogre::SceneNode;
@@ -49,6 +54,30 @@ sub dl_load_flags { $^O eq 'darwin' ? 0x00 : 0x01 }
 __PACKAGE__->bootstrap($VERSION);
 
 
+our %EXPORT_TAGS = (
+    'TextureFilterOptions' => [
+        qw(
+           TFO_NONE
+           TFO_BILINEAR
+           TFO_TRILINEAR
+           TFO_ANISOTROPIC
+       )
+    ],
+    'PolygonMode' => [
+        qw(
+           PM_POINTS
+           PM_WIREFRAME
+           PM_SOLID
+       )
+    ],
+);
+
+$EXPORT_TAGS{'all'} = [ map { @{ $EXPORT_TAGS{$_} } } keys %EXPORT_TAGS ];
+
+our @EXPORT_OK = @{ $EXPORT_TAGS{'all'} };
+our @EXPORT = ();
+
+
 1;
 
 __END__
